Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/progressbar_simpletest.py
    :caption: examples/progressbar_simpletest.py
    :linenos:


Color Scale
------------

Example showing how to change the progressbar color while updating the values

.. literalinclude:: ../examples/progressbar_displayio_blinka_color_scale.py
    :caption: examples/progressbar_displayio_blinka_color_scale.py
    :linenos:


Vertical Simple test
--------------------

Simple test to show a vertical Progress bar

.. literalinclude:: ../examples/progressbar_vertical_simpletest.py
    :caption: examples/progressbar_vertical_simpletest.py
    :linenos:


MatrixPortal Example
--------------------

Progressbar using the MatrixPortal

.. literalinclude:: ../examples/progressbar_matrixportal.py
    :caption: examples/examples/progressbar_matrixportal.py
    :linenos:



MagTag Example
---------------

Progressbar using the MagTag

.. literalinclude:: ../examples/progressbar_magtag_simpletest.py
    :caption: examples/progressbar_magtag_simpletest.py
    :linenos:


DisplayIO Blinka
----------------

Progressbar using DisplayIO in Blinka

.. literalinclude:: ../examples/progressbar_displayio_blinka.py
    :caption: examples/progressbar_displayio_blinka.py
    :linenos:

Combined ProgressBar
--------------------

Example showing both a Vertical and an Horizontal ProgressBar

.. literalinclude:: ../examples/progressbar_combined.py
    :caption: examples/progressbar_combined.py
    :linenos:


Accelerometer Example
---------------------

With this example you would be able to use the progress bar to display accelerometer data
in the X and Y directions

.. literalinclude:: ../examples/progressbar_accelerometer.py
    :caption: examples/progressbar_accelerometer.py
    :linenos:
